@@ -1,10 +1,12 @@
-import flask
 import logging
+from flask import Flask
+from flask.testing import FlaskClient
 from functools import cached_property
 from typing import List, Iterable, Tuple, Any, Optional
 
 from .guards import EndpointGuard
-from .endpoints import Endpoint, HealthCheck
+from .endpoint import Endpoint
+from .endpoints import HealthCheck, OpenApiSchema
 from .orchestration import \
     RequestOrchestrator, JsonBodyProvider, QueryStringProvider
 
@@ -24,7 +26,7 @@ class Application(object):
     def create(
             cls,
             *args,
-            endpoints: Iterable[Tuple[str, str, Endpoint]],
+            endpoints: Iterable[Tuple[str, str, Endpoint]] = (),
             health_check_path: Optional[str] = None,
             **kwargs,
     ) -> 'Application':
@@ -63,19 +65,26 @@ class Application(object):
         return app
 
     @cached_property
-    def _flask_app(self) -> flask.Flask:
+    def _flask_app(self) -> Flask:
         """
         TODO
         """
-        return flask.Flask(self.name)
+        return Flask(self.name)
 
     @property
-    def wsgi_app(self) -> flask.Flask:
+    def wsgi_app(self) -> Flask:
         """
         TODO
         """
         return self._flask_app
 
+    @property
+    def test_client(self) -> FlaskClient:
+        """
+        TODO
+        """
+        return self._flask_app.test_client()
+
     def add_endpoint(
             self,
             method: str,
